@@ -21,7 +21,7 @@
 #' This function reads constants, calibrations values and a lot of more from
 #' \emph{acqu} files.
 #'
-#' @param file \code{character}, path to corresponding fid file
+#' @param fidFile \code{character}, path to corresponding fid file
 #'  (e.g. \code{Pankreas_HB_L_061019_A10/0_a19/1/1SLin/fid})
 #' @param verbose \code{logical}, print verbose messages?
 #'
@@ -135,15 +135,17 @@
 ##
 .readAcquFile <- function(fidFile, verbose=FALSE) {
   acquFile <- sub(pattern="fid$", x=fidFile, replacement="acqu")
-
-  if (verbose) {
-    message("Reading metadata from ", sQuote(acquFile), " ...")
-  }
+  acquFiles <- c(acquFile, paste0(acquFile, "s"))
+  acquFile <- acquFiles[which.max(file.exists(acquFiles))]
 
   if (!file.exists(acquFile)) {
     stop("File ", sQuote(acquFile), " doesn't exists!")
   }
 
+  if (verbose) {
+    message("Reading metadata from ", sQuote(acquFile), " ...")
+  }
+
   con <- file(acquFile, "rt")
   acquLines <- readLines(con, n=-1)
   close(con)
@@ -191,7 +193,7 @@
   metaData$v1tofCalibration <-
     grepl("V1.0CTOF2CalibrationConstants",
           .grepAcquValue("##\\$NTBCal=", acquLines))
-  metaData$v1tofCalibrationConstants <- 
+  metaData$v1tofCalibrationConstants <-
     .extractV10CTOF2CalibrationConstants(
       .grepAcquValue("##\\$NTBCal=", acquLines)
     )
